"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../util/helpers");
var rgbf_1 = require("./rgbf");
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSL colour space is known as HSB in Photoshop.
 */
var FromHSL = /** @class */ (function () {
    function FromHSL() {
    }
    FromHSL.toRGBF = function (h, s, l) {
        var args = FromHSL.resolveArguments(h, s, l);
        if (args.s === 0) {
            return {
                r: l,
                g: l,
                b: l
            };
        }
        else {
            var C = (1 - Math.abs(2 * args.l - 1)) * args.s;
            var X = C * (1 - Math.abs((args.h / 60) % 2 - 1));
            var m = args.l - C / 2;
            if (args.h < 60) {
                return helpers_1.HueHelper.hueToRgbMatrix(C, X, 0, m);
            }
            if (args.h < 120) {
                return helpers_1.HueHelper.hueToRgbMatrix(X, C, 0, m);
            }
            if (args.h < 180) {
                return helpers_1.HueHelper.hueToRgbMatrix(0, C, X, m);
            }
            if (args.h < 240) {
                return helpers_1.HueHelper.hueToRgbMatrix(0, X, C, m);
            }
            if (args.h < 300) {
                return helpers_1.HueHelper.hueToRgbMatrix(X, 0, C, m);
            }
            return helpers_1.HueHelper.hueToRgbMatrix(C, 0, X, m);
        }
    };
    FromHSL.toRGB8 = function (h, s, l) {
        return rgbf_1.FromRGBF.toRGB8(FromHSL.toRGBF(h, s, l));
    };
    FromHSL.resolveArguments = function (h, s, l) {
        var argumentType = typeof h;
        if (argumentType === 'object' && h !== null) {
            return { h: h.h, s: h.s, l: h.l };
        }
        if (argumentType === 'number') {
            return { h: h, s: s, l: l };
        }
        throw new TypeError('Unknown arguments passed');
    };
    return FromHSL;
}());
exports.FromHSL = FromHSL;
