"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../util/helpers");
var rgbf_1 = require("./rgbf");
/**
 * Converts HSL colours for either RGB 8 bit or RGB float.
 * HSV is an alternative version of HSL. Hue component is the same,
 * but S and V are calculated a bit differently from S and L in HSL.
 */
var FromHSV = /** @class */ (function () {
    function FromHSV() {
    }
    FromHSV.toRGBF = function (h, s, v) {
        var args = FromHSV.resolveArguments(h, s, v);
        if (args.s === 0) {
            return { r: v, g: v, b: v };
        }
        var C = args.v * args.s;
        var X = C * (1 - Math.abs((args.h / 60) % 2 - 1));
        var m = args.v - C;
        if (args.h < 60) {
            return helpers_1.HueHelper.hueToRgbMatrix(C, X, 0, m);
        }
        if (args.h < 120) {
            return helpers_1.HueHelper.hueToRgbMatrix(X, C, 0, m);
        }
        if (args.h < 180) {
            return helpers_1.HueHelper.hueToRgbMatrix(0, C, X, m);
        }
        if (args.h < 240) {
            return helpers_1.HueHelper.hueToRgbMatrix(0, X, C, m);
        }
        if (args.h < 300) {
            return helpers_1.HueHelper.hueToRgbMatrix(X, 0, C, m);
        }
        return helpers_1.HueHelper.hueToRgbMatrix(C, 0, X, m);
    };
    FromHSV.toRGB8 = function (h, s, v) {
        return rgbf_1.FromRGBF.toRGB8(FromHSV.toRGBF(h, s, v));
    };
    FromHSV.resolveArguments = function (h, s, v) {
        var argumentType = typeof h;
        if (argumentType === 'object' && h !== null) {
            return { h: h.h, s: h.s, v: h.v };
        }
        if (argumentType === 'number') {
            return { h: h, s: s, v: v };
        }
        throw new TypeError('Unknown arguments passed');
    };
    return FromHSV;
}());
exports.FromHSV = FromHSV;
