"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rgbf_1 = require("./rgbf");
var helpers_1 = require("../util/helpers");
/**
 * Converter from 8 bit RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
var FromRGB8 = /** @class */ (function () {
    function FromRGB8() {
    }
    FromRGB8.toRGBF = function (r, g, b) {
        var args = FromRGB8.resolveArguments(r, g, b);
        return {
            r: args.r / 255,
            g: args.g / 255,
            b: args.b / 255
        };
    };
    FromRGB8.toHSL = function (r, g, b) {
        return rgbf_1.FromRGBF.toHSL(FromRGB8.toRGBF(r, g, b));
    };
    FromRGB8.toHSV = function (r, g, b) {
        return rgbf_1.FromRGBF.toHSV(FromRGB8.toRGBF(r, g, b));
    };
    FromRGB8.toXYZ = function (r, g, b) {
        return rgbf_1.FromRGBF.toXYZ(FromRGB8.toRGBF(r, g, b));
    };
    FromRGB8.toHex = function (r, g, b) {
        var args = FromRGB8.resolveArguments(r, g, b);
        return "" + helpers_1.HexHelper.numberToHex(args.r) + helpers_1.HexHelper.numberToHex(args.g) + helpers_1.HexHelper.numberToHex(args.b);
    };
    FromRGB8.toRGBAHex = function (r, g, b, a) {
        var args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return "" + FromRGB8.toHex(args) + helpers_1.HexHelper.numberToHex(args.a);
    };
    FromRGB8.toARGBHex = function (r, g, b, a) {
        var args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return "" + helpers_1.HexHelper.numberToHex(args.a) + FromRGB8.toHex(args);
    };
    FromRGB8.toCssRgb = function (r, g, b) {
        var args = FromRGB8.resolveArguments(r, g, b);
        return "rgb(" + args.r + ", " + args.g + ", " + args.b + ")";
    };
    FromRGB8.toCssRgba = function (r, g, b, a) {
        var args = FromRGB8.resolveRGBAArguments(r, g, b, a);
        return "rgba(" + args.r + ", " + args.g + ", " + args.b + ", " + (args.a / 255).toFixed(2) + ")";
    };
    FromRGB8.toLab = function (r, g, b) {
        return rgbf_1.FromRGBF.toLab(FromRGB8.toRGBF(FromRGB8.resolveArguments(r, g, b)));
    };
    FromRGB8.resolveArguments = function (r, g, b) {
        var argumentType = typeof r;
        if (argumentType === 'object' && r !== null) {
            return { r: r.r, g: r.g, b: r.b };
        }
        if (argumentType === 'number') {
            return { r: r, g: g, b: b };
        }
        throw new TypeError('Unknown arguments passed');
    };
    FromRGB8.resolveRGBAArguments = function (r, g, b, a) {
        var aType = typeof r;
        var bType = typeof g;
        if (aType === 'object' && r !== null && bType === 'number') {
            return { r: r.r, g: r.g, b: r.b, a: g };
        }
        if (aType === 'number') {
            return { r: r, g: g, b: b, a: a };
        }
        throw new TypeError('Unknown arguments passed');
    };
    return FromRGB8;
}());
exports.FromRGB8 = FromRGB8;
