"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helpers_1 = require("../util/helpers");
var matrix_1 = require("../util/matrix");
var xyz_1 = require("./xyz");
/**
 * Converter from float number RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
var FromRGBF = /** @class */ (function () {
    function FromRGBF() {
    }
    FromRGBF.toRGB8 = function (r, g, b) {
        var args = FromRGBF.resolveArguments(r, g, b);
        return {
            r: Math.round(args.r * 255),
            g: Math.round(args.g * 255),
            b: Math.round(args.b * 255)
        };
    };
    FromRGBF.toHSL = function (r, g, b) {
        var args = FromRGBF.resolveArguments(r, g, b);
        var basis = helpers_1.HueHelper.calculateBasisFromRGBF(args);
        var l = (basis.max + basis.min) / 2;
        var s;
        if (basis.delta === 0) {
            s = 0;
        }
        else {
            s = l < 0.5 ? basis.delta / (basis.max + basis.min) : basis.delta / (2 - basis.max - basis.min);
        }
        return {
            h: basis.hue,
            s: s,
            l: l
        };
    };
    FromRGBF.toHSV = function (r, g, b) {
        var args = FromRGBF.resolveArguments(r, g, b);
        var basis = helpers_1.HueHelper.calculateBasisFromRGBF(args);
        return {
            h: basis.hue,
            s: basis.max === 0 ? 0 : basis.delta / basis.max,
            v: basis.max
        };
    };
    FromRGBF.toXYZ = function (r, g, b) {
        var args = FromRGBF.resolveArguments(r, g, b);
        var pr = helpers_1.XYZHelper.pivotRGB(args.r);
        var pg = helpers_1.XYZHelper.pivotRGB(args.g);
        var pb = helpers_1.XYZHelper.pivotRGB(args.b);
        return {
            x: pr * matrix_1.Matrix.sRGBtoXYZ.r[0] + pg * matrix_1.Matrix.sRGBtoXYZ.r[1] + pb * matrix_1.Matrix.sRGBtoXYZ.r[2],
            y: pr * matrix_1.Matrix.sRGBtoXYZ.g[0] + pg * matrix_1.Matrix.sRGBtoXYZ.g[1] + pb * matrix_1.Matrix.sRGBtoXYZ.g[2],
            z: pr * matrix_1.Matrix.sRGBtoXYZ.b[0] + pg * matrix_1.Matrix.sRGBtoXYZ.b[1] + pb * matrix_1.Matrix.sRGBtoXYZ.b[2]
        };
    };
    FromRGBF.toLab = function (r, g, b) {
        return xyz_1.FromXYZ.toLab(FromRGBF.toXYZ(FromRGBF.resolveArguments(r, g, b)));
    };
    FromRGBF.resolveArguments = function (r, g, b) {
        var argumentType = typeof r;
        if (argumentType === 'object' && r !== null) {
            return { r: r.r, g: r.g, b: r.b };
        }
        if (argumentType === 'number') {
            return { r: r, g: g, b: b };
        }
        throw new TypeError('Unknown arguments passed');
    };
    return FromRGBF;
}());
exports.FromRGBF = FromRGBF;
