"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var matrix_1 = require("../util/matrix");
var helpers_1 = require("../util/helpers");
var rgbf_1 = require("./rgbf");
var xyz_refs_1 = require("../util/xyz-refs");
var FromXYZ = /** @class */ (function () {
    function FromXYZ() {
    }
    FromXYZ.toRGBF = function (x, y, z) {
        var args = FromXYZ.resolveArguments(x, y, z);
        var result = {
            r: args.x * matrix_1.Matrix.XYZtosRGB.x[0] + args.y * matrix_1.Matrix.XYZtosRGB.x[1] + args.z * matrix_1.Matrix.XYZtosRGB.x[2],
            g: args.x * matrix_1.Matrix.XYZtosRGB.y[0] + args.y * matrix_1.Matrix.XYZtosRGB.y[1] + args.z * matrix_1.Matrix.XYZtosRGB.y[2],
            b: args.x * matrix_1.Matrix.XYZtosRGB.z[0] + args.y * matrix_1.Matrix.XYZtosRGB.z[1] + args.z * matrix_1.Matrix.XYZtosRGB.z[2]
        };
        // RGBF values can not be bigger than 1 no matter which rounding errors we have
        result.r = Math.max(Math.min(helpers_1.XYZHelper.pivotXYZ(result.r), 1), 0);
        result.g = Math.max(Math.min(helpers_1.XYZHelper.pivotXYZ(result.g), 1), 0);
        result.b = Math.max(Math.min(helpers_1.XYZHelper.pivotXYZ(result.b), 1), 0);
        return result;
    };
    FromXYZ.toRGB8 = function (x, y, z) {
        return rgbf_1.FromRGBF.toRGB8(FromXYZ.toRGBF(x, y, z));
    };
    FromXYZ.toLab = function (x, y, z) {
        // We assume D65 at 2deg illuminant here which corresponds to sRGB.
        var args = FromXYZ.rebase(FromXYZ.resolveArguments(x, y, z), xyz_refs_1.XYZRefs.D65_2d);
        args.x = helpers_1.XYZHelper.pivotToLab(args.x);
        args.y = helpers_1.XYZHelper.pivotToLab(args.y);
        args.z = helpers_1.XYZHelper.pivotToLab(args.z);
        return {
            l: 116 * args.y - 16,
            a: 500 * (args.x - args.y),
            b: 200 * (args.y - args.z)
        };
    };
    FromXYZ.rebase = function (xyz, illuminant) {
        var result = {
            x: xyz.x / illuminant.x,
            y: xyz.y / illuminant.y,
            z: xyz.z / illuminant.z
        };
        if (result.x > 1) {
            result.x = 1;
        }
        if (result.y > 1) {
            result.y = 1;
        }
        if (result.z > 1) {
            result.z = 1;
        }
        return result;
    };
    FromXYZ.resolveArguments = function (x, y, z) {
        var argumentType = typeof x;
        if (argumentType === 'object' && x !== null) {
            return { x: x.x, y: x.y, z: x.z };
        }
        if (argumentType === 'number') {
            return { x: x, y: y, z: z };
        }
        throw new TypeError('Unknown arguments passed');
    };
    return FromXYZ;
}());
exports.FromXYZ = FromXYZ;
